@@ -7,6 +7,8 @@ var dir_04d2bd150f7cc849eeec70b9b0fdccb1 =
     [ "exif-data.h", "exif-data_8h.html", "exif-data_8h" ],
     [ "exif-entry.h", "exif-entry_8h.html", "exif-entry_8h" ],
     [ "exif-format.h", "exif-format_8h.html", "exif-format_8h" ],
+    [ "exif-gps-ifd.c", "exif-gps-ifd_8c.html", "exif-gps-ifd_8c" ],
+    [ "exif-gps-ifd.h", "exif-gps-ifd_8h.html", "exif-gps-ifd_8h" ],
     [ "exif-ifd.h", "exif-ifd_8h_source.html", null ],
     [ "exif-loader.h", "exif-loader_8h.html", "exif-loader_8h" ],
     [ "exif-log.h", "exif-log_8h.html", "exif-log_8h" ],
